ColumnOption

Enum ColumnOption 

pub enum ColumnOption {
    Null,
    NotNull,
    DefaultValue(Expr),
    DefaultValueInternal {
        persisted: Box<[u8]>,
        expr: Option<Expr>,
    },
    Unique {
        is_primary: bool,
    },
    ForeignKey {
        foreign_table: ObjectName,
        referred_columns: Vec<Ident>,
        on_delete: Option<ReferentialAction>,
        on_update: Option<ReferentialAction>,
    },
    Check(Expr),
    DialectSpecific(Vec<Token>),
    GeneratedColumns(Expr),
}
ColumnOptions are modifiers that follow a column definition in a CREATE TABLE statement.

Variants



Null

NULL



NotNull

NOT NULL



DefaultValue(Expr)

DEFAULT <restricted-expr>



DefaultValueInternal

Default value from previous bound DefaultColumnDesc. Used internally for schema change and should not be specified by users.

Fields

persisted: Box<[u8]>

Protobuf encoded DefaultColumnDesc.

expr: Option<Expr>

Optional AST for unparsing. If None, the default value will be shown as DEFAULT INTERNAL which is for demonstrating and should not be specified by users.



Unique

{ PRIMARY KEY | UNIQUE }

Fields

is_primary: bool


ForeignKey

A referential integrity constraint ([FOREIGN KEY REFERENCES <foreign_table> (<referred_columns>) { [ON DELETE <referential_action>] [ON UPDATE <referential_action>] | [ON UPDATE <referential_action>] [ON DELETE <referential_action>] }).

Fields

foreign_table: ObjectName
referred_columns: Vec<Ident>


Check(Expr)

CHECK (<expr>)



DialectSpecific(Vec<Token>)

Dialect-specific options, such as:

  • MySQL’s AUTO_INCREMENT or SQLite’s AUTOINCREMENT


GeneratedColumns(Expr)

AS ( <generation_expr> )`