FormatEncodeOptions

Struct FormatEncodeOptions 

pub struct FormatEncodeOptions {
    pub format: Format,
    pub row_encode: Encode,
    pub row_options: Vec<SqlOption>,
    pub key_encode: Option<Encode>,
}
FORMAT ... ENCODE ... [(a=b, ...)] [KEY ENCODE ...]

Fields

format: Formatrow_encode: Encoderow_options: Vec<SqlOption>key_encode: Option<Encode>

Implementations

Source

impl FormatEncodeOptions

pub const fn plain_json() -> Self

pub const fn debezium_json() -> Self

Create a new source schema with Debezium format and Json encoding.

pub const fn debezium_mongo_json() -> Self

pub const fn native() -> Self

Create a new source schema with Native format and encoding.

pub const fn none() -> Self

Create a new source schema with None format and encoding. Used for self-explanatory source like iceberg.

pub fn row_options(&self) -> &[SqlOption]