FunctionArgList

Struct FunctionArgList 

pub struct FunctionArgList {
    pub distinct: bool,
    pub args: Vec<FunctionArg>,
    pub variadic: bool,
    pub order_by: Vec<OrderByExpr>,
    pub ignore_nulls: bool,
}
A list of function arguments, including additional modifiers like DISTINCT or ORDER BY. This basically holds all the information between the ( and ) in a function call.

Fields

distinct: bool

Aggregate function calls may have a DISTINCT, e.g. count(DISTINCT x).

args: Vec<FunctionArg>variadic: bool

Whether the last argument is variadic, e.g. foo(a, b, VARIADIC c).

order_by: Vec<OrderByExpr>

Aggregate function calls may have an ORDER BY, e.g. array_agg(x ORDER BY y).

ignore_nulls: bool

Window function calls may have an IGNORE NULLS, e.g. first_value(x IGNORE NULLS).

Implementations

Source

impl FunctionArgList

pub fn empty() -> Self

pub fn args_only(args: Vec<FunctionArg>) -> Self

pub fn is_args_only(&self) -> bool

pub fn for_agg( distinct: bool, args: Vec<FunctionArg>, order_by: Vec<OrderByExpr>, ) -> Self