TokenStream

Trait TokenStream 

pub trait TokenStream:
    Stream<Token = TokenWithLocation>
    + StreamIsPartial
    + Default
    + ParseV1 { }
Bundle trait requirements from winnow, so that we don’t need to write them everywhere.

All combinators should accept a generic S that implements TokenStream.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<S> TokenStream for S
where S: Stream<Token = TokenWithLocation> + StreamIsPartial + Default + ParseV1,